ExpectBehaviour

Struct ExpectBehaviour 

pub struct ExpectBehaviour {
    pub stmt_id: usize,
    pub bound: Rc<dyn Any>,
    /* private fields */
}
Stores the state of a expected behaviour.

Fields

stmt_id: usize

The unique id of the behaviour within the mocked method to which it belongs.

bound: Rc<dyn Any>

The bound variables available to the behaviour’s ArgMatcher.

Implementations

Source

impl ExpectBehaviour

pub fn with_times( times: usize, stmt_id: usize, bound: Rc<dyn Any>, stmt_repr: &str, ) -> Self

Creates a new behaviour which is satisfied if matched times.

pub fn with_at_least( at_least_times: usize, stmt_id: usize, bound: Rc<dyn Any>, stmt_repr: &str, ) -> Self

Creates a new behaviour which is satisfied if matched at_least_times.

pub fn with_at_most( at_most_times: usize, stmt_id: usize, bound: Rc<dyn Any>, stmt_repr: &str, ) -> Self

Creates a new behaviour which is satisfied if matched at_most_times.

pub fn with_between( at_least_times: usize, at_most_times: usize, stmt_id: usize, bound: Rc<dyn Any>, stmt_repr: &str, ) -> Self

Creates a new behaviour which is satisfied if matched between [at_least_times, at_most_times] (inclusive endpoints).

pub fn matched(&self)

Notifies the behaviour that it has been matched.

pub fn is_saturated(&self) -> bool

Returns true iff current number of matches would satify the behaviours expected repetitions.

pub fn describe(&self) -> &str

Returns a description of the behaviour.