pub struct GivenBehaviour {
pub stmt_id: usize,
pub bound: Rc<dyn Any>,
/* private fields */
}Expand description
Stores the state of a given behaviour.
Fields
stmt_id: usizeThe unique id of the behaviour within the mocked method to which it belongs.
bound: Rc<dyn Any>The bound variables available to the behaviour’s ArgMatcher.
Implementations
Sourceimpl GivenBehaviour
impl GivenBehaviour
Sourcepub fn with(stmt_id: usize, bound: Rc<dyn Any>, stmt_repr: &str) -> Self
pub fn with(stmt_id: usize, bound: Rc<dyn Any>, stmt_repr: &str) -> Self
Creates a new behaviour which is never exhausted.
Sourcepub fn with_times(
times: usize,
stmt_id: usize,
bound: Rc<dyn Any>,
stmt_repr: &str,
) -> Self
pub fn with_times( times: usize, stmt_id: usize, bound: Rc<dyn Any>, stmt_repr: &str, ) -> Self
Creates a new behaviour which is never exhausted after being matched times.
Sourcepub fn is_saturated(&self) -> bool
pub fn is_saturated(&self) -> bool
Returns true iff the behaviour is exhausted.